==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>Stil Treguesi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>Mënyra Modë</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>Mënyra Efikase</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>Pozicion</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>Vendose Majtas</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>Vendose Në Krye</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>Vendose Në Qendër</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>Në krye</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>Në fund</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>Mbaje të Shfaqur</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>Mbaje të Fshehur</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>Fshehje e Mençur</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>Rregullim Paneli</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Stil Treguesi</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mënyra Modë</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mënyra Efikase</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mënyra Klasike</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mënyra e Qendërzuar</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozicion</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Në krye</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Në fund</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mbaje të Shfaqur</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mbaje të Fshehur</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Fshehje e Mençur</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Rregullim Paneli</translation>
    </message>
</context>
</TS>
